@@ -26,6 +26,7 @@ sub factor {
   
   # default - levels
   unless (defined $x_levels) {
+    $DB::single = 1;
     $x_levels = Rstats::Func::sort($r, unique($r, $x1), {'na.last' => Rstats::Func::TRUE($r)});
   }
   
@@ -1065,6 +1066,7 @@ sub sub {
         $x =~ s/$pattern/$replacement/i;
       }
       else {
+        $DB::single = 1;
         $x =~ s/$pattern/$replacement/;
       }
       push @$x2_values, "$x";
@@ -2239,12 +2241,14 @@ sub rnorm {
   
   # Random numbers(standard deviation)
   my @x1_elements;
+  
+  my $pi = $r->pi->value;
   for (1 .. $count) {
     my ($rand1, $rand2) = (rand, rand);
     while ($rand1 == 0) { $rand1 = rand(); }
     
     my $rnorm = ($sd * CORE::sqrt(-2 * CORE::log($rand1))
-      * CORE::sin(2 * Rstats::Util::pi() * $rand2))
+      * CORE::sin(2 * $pi * $rand2))
       + $mean;
     
     push @x1_elements, $rnorm;
